===========
FuncVerbNet
===========

.. image:: https://raw.githubusercontent.com/FudanSELab/funcverbnet/dev-duyi/logo.png
        :height: 100px
        :scale: 100%
        :align: left

.. image:: https://img.shields.io/pypi/v/funcverbnet.svg
        :target: https://pypi.python.org/pypi/funcverbnet

.. image:: https://img.shields.io/travis/FudanSELab/funcverbnet.svg
        :target: https://travis-ci.com/FudanSELab/funcverbnet

.. image:: https://readthedocs.org/projects/funcverbnet/badge/?version=latest
        :target: https://funcverbnet.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Provides a knowledge system constructed from functionality categories, verbs, and phrase patterns, as well as functionality for fine-grained analysis of functionality descriptions based on this knowledge system


* Free software: BSD license
* Documentation: https://funcverbnet.readthedocs.io.


Features
--------

* TODO

1. Obtain all functionality categories, functionality verbs and phase patters.
2. Given a functionality description sentence, identify its functionality category, functionality verbs and phase patters.

Citation
--------

Please cite the following paper if you used this in your works!

::

    @inproceedings{DBLP:conf/sigsoft/Xie0LTXZZ20,
      author    = {Wenkai Xie and
                   Xin Peng and
                   Mingwei Liu and
                   Christoph Treude and
                   Zhenchang Xing and
                   Xiaoxin Zhang and
                   Wenyun Zhao},
      editor    = {Prem Devanbu and
                   Myra B. Cohen and
                   Thomas Zimmermann},
      title     = {{API} method recommendation via explicit matching of functionality
                   verb phrases},
      booktitle = {{ESEC/FSE} '20: 28th {ACM} Joint European Software Engineering Conference
                   and Symposium on the Foundations of Software Engineering, Virtual
                   Event, USA, November 8-13, 2020},
      pages     = {1015--1026},
      publisher = {{ACM}},
      year      = {2020},
    }


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
